/* Shopper
 * Copyright (C) 2008 David Greaves
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */
#include "shopper.h"           // automake, i8n, gettext
#include <gtkmm.h>
#include <hildon-fmmm.h>
#include <glibmm.h>
#include "labeltext.h"

//#define DEBUG(...) cerr << __VA_ARGS__
#define DEBUG(...)

// LabelEntry - a label that turns into a textbox when clicked

LabelEntry::LabelEntry(const Glib::ustring &   	 label_text) :
	label(label_text)
{
	evbox.add(label);
	evbox.signal_button_press_event()
		.connect( sigc::mem_fun(*this, &LabelEntry::show_entry) );
}


bool LabelEntry::show_text(GdkEventButton* ev)
{
	DEBUG("Pressed button " << ev->button << "\n");
	entry = new Gtk::Entry();
	entry->set_activates_default(false);
	entry->set_width_chars(15); // FIXME
	entry->set_text(myitem->get_note());
	// self-destruct on unfocus or activate
	entry->signal_activate()  // FIXME : Crashes. activate conflicts withe note_b.remove()
		.connect( sigc::mem_fun(*this,
								(void (Shopper::ItemView::*)())
								&Shopper::ItemView::show_label) );
	entry->signal_button_press_event()
		.connect( sigc::mem_fun(*this,
								(bool (Shopper::ItemView::*)(GdkEventButton*))
								&Shopper::ItemView::show_label) );
	entry->signal_focus_out_event()
		.connect( sigc::mem_fun(*this,
								(bool (Shopper::ItemView::*)(GdkEventFocus*))
								&Shopper::ItemView::show_label) );
		
	note_b.remove(); // remove label
	note_b.add(*entry);
	entry->show();
	entry->grab_focus();
}
bool LabelEntry::show_label(GdkEventFocus* ev)
{
	if (! ev->in){
		note_show_label();
	}
	return true; // FIXME why true? Something to do with ev propogation?
}
bool LabelEntry::show_label(GdkEventButton* ev)
{
	if (ev->button ==3 ){
		DEBUG("Middle click\n");
		note_show_label();
	}
	return true; // FIXME why true? Something to do with ev propogation?
}
void LabelEntry::show_label()
{
	note_b.remove(); // remove note_edit
	note_b.add(label);
	note.show();
//FIXME:::
//myitem->set_note(note_edit->get_text()); // Setting the data
	// will call an
	// update on the note
	delete entry;
	entry=NULL;
}
